# PathLit Python SDK

PathLit provides developers and quants with APIs that take the complexity out of writing code for financial portfolio calculations.

We provide a scalable and secure API-first engine with a library of investment methodologies that can calculate weights, run simulations, auto-backtest and more.

You bring product identifiers, we do the rest.

This python package acts as a simple interface with the PathLit API [reference](https://www.pathlit.io/docs/api/overview)

## Using the package

**pre-requisite:** A PathLit account is required to interact with the API with a unique key to the account. It can be done at the [account creation page](https://www.pathlit.io/signup).

### installation

`pip3 install pathlit`
